package com.yeejoin.amos.api.tool.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yeejoin.amos.api.tool.face.model.ApiListModel;
import com.yeejoin.amos.api.tool.face.service.ApiListService;
import com.yeejoin.amos.api.tool.face.service.ApiTreeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.typroject.tyboot.core.foundation.enumeration.UserType;
import org.typroject.tyboot.core.restful.doc.TycloudOperation;
import org.typroject.tyboot.core.restful.utils.ResponseHelper;
import org.typroject.tyboot.core.restful.utils.ResponseModel;

import javax.servlet.http.HttpServletRequest;
import java.util.List;


/**
 * @author r
 */
@RestController
@Api(tags = "Api列表")
@RequestMapping(value = "/demo/studio_data_api")
public class ApiListResource {

    @Autowired
    ApiListService apiListService;

    @Autowired
    ApiTreeService apiTreeService;

    /**
     * 新增
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
    @PostMapping(value = "/save")
    @ApiOperation(httpMethod = "POST", value = "新增", notes = "新增")
    public ResponseModel<ApiListModel> save(@RequestBody ApiListModel model)
    {
        model= apiListService.createWithModel(model);
        return ResponseHelper.buildResponse(model);
    }
    /**
     * 根据sequenceNbr更新
     * @param sequenceNbr 主键
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
    @PutMapping(value = "/{sequenceNbr}")
    @ApiOperation(httpMethod = "PUT", value = "根据sequenceNbr更新", notes = "根据sequenceNbr更新")
    public ResponseModel<ApiListModel> updateBySequenceNbrApiList(@RequestBody ApiListModel model, @PathVariable(value = "sequenceNbr") Long sequenceNbr) {
        model.setSequenceNbr(sequenceNbr);
        return ResponseHelper.buildResponse(apiListService.updateWithModel(model));
    }
    /**
     * 根据sequenceNbr删除
     * @param sequenceNbr 主键
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
    @DeleteMapping(value = "/{sequenceNbr}")
    @ApiOperation(httpMethod = "DELETE", value = "根据sequenceNbr删除", notes = "根据sequenceNbr删除")
    public ResponseModel<Boolean> deleteBySequenceNbr(HttpServletRequest request, @PathVariable(value = "sequenceNbr") Long sequenceNbr){
        return ResponseHelper.buildResponse(apiListService.removeById(sequenceNbr));
    }
    /**
     * 根据sequenceNbr查询
     * @param sequenceNbr  主键
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
    @GetMapping(value = "/{sequenceNbr}")
    @ApiOperation(httpMethod = "GET",value = "根据sequenceNbr查询单个",  notes = "根据sequenceNbr查询单个")
    public ResponseModel<ApiListModel> seleteOne(@PathVariable Long sequenceNbr)
    {
        return ResponseHelper.buildResponse(apiListService.queryBySeq(sequenceNbr));
    }


    /**
     * 列表分页查询
     *@param current 当前页
     *@param current 每页大小
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
    @GetMapping(value = "/page")
    @ApiOperation(httpMethod = "GET",value = "分页查询",  notes = "分页查询")
    public ResponseModel<Page<ApiListModel>> queryForPage(@RequestParam(value = "current") int current, @RequestParam(value = "size") int size, @RequestParam(value = "sequenceNbr") Long sequenceNbr)
    {
        Page<ApiListModel> page=new Page<ApiListModel>();
        page.setCurrent(current);
        page.setSize(size);
        return ResponseHelper.buildResponse(apiListService.queryForApiListPage(page, apiTreeService.queryCodeBySeq(sequenceNbr)));
    }
    /**
     *列表全部数据查询
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
    @ApiOperation(httpMethod = "GET",value = "列表全部数据查询",   notes = "列表全部数据查询")
    @GetMapping(value = "/list")
    public ResponseModel<List<ApiListModel>>  selectForList()
    {
        return ResponseHelper.buildResponse(apiListService.queryForApiListList());
    }
}
