package com.yeejoin.amos.api.tool.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yeejoin.amos.api.tool.face.model.TplCateModel;
import com.yeejoin.amos.api.tool.face.model.TplTreeModel;
import com.yeejoin.amos.api.tool.face.service.DesignerService;
import com.yeejoin.amos.api.tool.face.service.TplCateService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.typroject.tyboot.core.foundation.enumeration.UserType;
import org.typroject.tyboot.core.restful.doc.TycloudOperation;
import org.typroject.tyboot.core.restful.utils.ResponseHelper;
import org.typroject.tyboot.core.restful.utils.ResponseModel;

import javax.servlet.http.HttpServletRequest;
import java.util.List;


/**
 * @author r
 */
@RestController
@Api(tags = "模板树")
@RequestMapping(value = "/demo/studio_template_category")
public class TplCateResource {

    @Autowired
    TplCateService tplCateService;

    @Autowired
    DesignerService designerService;
    /**
     * 新增
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
    @PostMapping(value = "/save")
    @ApiOperation(httpMethod = "POST", value = "新增", notes = "新增")
    public ResponseModel<TplCateModel> save(@RequestBody TplCateModel model){

        model.setIcon("");
        model.setIsDelete(false);
        model.setSequenceNbr(null);
        model= tplCateService.createWithModel(model);

        return ResponseHelper.buildResponse(model);
    }


    /**
     * 根据sequenceNbr更新
     * @param sequenceNbr 主键
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
    @PutMapping(value = "/{sequenceNbr}")
    @ApiOperation(httpMethod = "PUT", value = "根据sequenceNbr更新", notes = "根据sequenceNbr更新")
    public ResponseModel<TplCateModel> updateBySequenceNbrTplTree(@RequestBody TplCateModel model, @PathVariable(value = "sequenceNbr") Long sequenceNbr) {
        model.setSequenceNbr(sequenceNbr);
        return ResponseHelper.buildResponse(tplCateService.updateWithModel(model));
    }
    /**
     * 根据sequenceNbr删除
     * @param sequenceNbr 主键
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
    @DeleteMapping(value = "/{sequenceNbr}")
    @ApiOperation(httpMethod = "DELETE", value = "根据sequenceNbr删除", notes = "根据sequenceNbr删除")
    public ResponseModel<Boolean> deleteBySequenceNbr(HttpServletRequest request, @PathVariable(value = "sequenceNbr") Long sequenceNbr){
        return ResponseHelper.buildResponse(tplCateService.removeById(sequenceNbr));
    }
    /**
     * 根据sequenceNbr查询
     * @param sequenceNbr  主键
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
    @GetMapping(value = "/{sequenceNbr}")
    @ApiOperation(httpMethod = "GET",value = "根据sequenceNbr查询单个",  notes = "根据sequenceNbr查询单个")
    public ResponseModel<TplCateModel> seleteOne(@PathVariable Long sequenceNbr)
    {
        return ResponseHelper.buildResponse(tplCateService.queryBySeq(sequenceNbr));
    }
    /**
     *列表全部数据查询
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
    @ApiOperation(httpMethod = "GET",value = "列表全部数据查询",   notes = "列表全部数据查询")
    @GetMapping(value = "/list")
    public ResponseModel<List<TplCateModel>>  selectForList()
    {
        return ResponseHelper.buildResponse(tplCateService.queryForTplCateList());
    }

    /**
     * 列表分页查询
     *@param current 当前页
     *@param current 每页大小
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
    @GetMapping(value = "/page")
    @ApiOperation(httpMethod = "GET",value = "分页查询",  notes = "分页查询")
    public ResponseModel<Page<TplCateModel>> queryForPage(@RequestParam(value = "current") int current, @RequestParam(value = "size") int size)
    {
        Page<TplCateModel> page=new Page<TplCateModel>();
        page.setCurrent(current);
        page.setSize(size);
        return ResponseHelper.buildResponse(tplCateService.queryForTplCatePage(page));
    }
    /**
     * 树形查询
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
    @GetMapping(value = "/tree")
    @ApiOperation(httpMethod = "GET",value = "树形查询",  notes = "树形查询")
    public ResponseModel<List<TplTreeModel>> selectForTree(){

        return ResponseHelper.buildResponse(designerService.getList());
    }

}
