package com.yeejoin.amos.api.tool.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yeejoin.amos.api.tool.face.model.TplListModel;
import com.yeejoin.amos.api.tool.face.model.TplVoModel;
import com.yeejoin.amos.api.tool.face.service.TplListService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.beanutils.ConvertUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.typroject.tyboot.core.foundation.enumeration.UserType;
import org.typroject.tyboot.core.restful.doc.TycloudOperation;
import org.typroject.tyboot.core.restful.utils.ResponseHelper;
import org.typroject.tyboot.core.restful.utils.ResponseModel;

import javax.servlet.http.HttpServletRequest;
import java.util.List;


/**
 * @author r
 */
@RestController
@Api(tags = "模板列表")
@RequestMapping(value = "/demo/studio_template")
public class TplListResource {

    @Autowired
    TplListService tplListService;

    /**
     * 新增
     *
     * @return
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY, needAuth = false)
    @PostMapping(value = "/save")
    @ApiOperation(httpMethod = "POST", value = "新增", notes = "新增")
    public ResponseModel<TplListModel> save(@RequestBody TplVoModel tplVoModel) throws Exception {
        tplVoModel.setIsDel(false);
        tplVoModel.setDisplayName(tplVoModel.getComName());
        TplListModel tplListModel = new TplListModel();
        BeanUtils.copyProperties(tplVoModel, tplListModel, "thumbs", "sketches");
        if (tplVoModel.getThumbs().size() != 0)
            tplListModel.setThumb(tplVoModel.getThumbs().get(0).getUrl());
        if (tplVoModel.getSketches().size() != 0)
            tplListModel.setSketch(tplVoModel.getSketches().get(0).getUrl());
        tplListModel = tplListService.createWithModel(tplListModel);
        return ResponseHelper.buildResponse(tplListModel);
    }

    /**
     * 根据sequenceNbr更新
     *
     * @param sequenceNbr 主键
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY, needAuth = false)
    @PutMapping(value = "/{sequenceNbr}")
    @ApiOperation(httpMethod = "PUT", value = "根据sequenceNbr更新", notes = "根据sequenceNbr更新")
    public ResponseModel<TplListModel> updateBySequenceNbrTplList(@RequestBody TplVoModel tplVoModel, @PathVariable(value = "sequenceNbr") Long sequenceNbr) {
        tplVoModel.setSequenceNbr(sequenceNbr);
        tplVoModel.setDisplayName(tplVoModel.getComName());
        TplListModel tplListModel = new TplListModel();
        BeanUtils.copyProperties(tplVoModel, tplListModel, "thumbs", "sketches");
        if (tplVoModel.getThumbs().size() != 0)
            tplListModel.setThumb(tplVoModel.getThumbs().get(0).getUrl());
        if (tplVoModel.getSketches().size() != 0)
            tplListModel.setSketch(tplVoModel.getSketches().get(0).getUrl());

        return ResponseHelper.buildResponse(tplListService.updateWithModel(tplListModel));
    }

    /**
     * 根据sequenceNbr删除
     *
     * @param sequenceNbr 主键
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY, needAuth = false)
    @DeleteMapping(value = "/{sequenceNbr}")
    @ApiOperation(httpMethod = "DELETE", value = "根据sequenceNbr删除", notes = "根据sequenceNbr删除")
    public ResponseModel<Boolean> deleteBySequenceNbr(HttpServletRequest request, @PathVariable(value = "sequenceNbr") Long sequenceNbr) {
        return ResponseHelper.buildResponse(tplListService.removeById(sequenceNbr));
    }
    /**
     * 根据sequenceNbr批量删除
     *
     * @param sequenceNbr 主键
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY, needAuth = false)
    @DeleteMapping(value = "/s/{sequenceNbr}")
    @ApiOperation(httpMethod = "DELETE", value = "批量删除", notes = "根据sequenceNbr删除")
    public ResponseModel<Boolean[]> deleteBySequenceNbr(HttpServletRequest request, @PathVariable(value = "sequenceNbr") String sequenceNbr) {
        String Nbr[] = sequenceNbr.split(",");
        Long[] seq = (Long[])ConvertUtils.convert(Nbr, Long.class);
        Boolean Nbr2[] = new Boolean[Nbr.length];
        for (int i = 0;i < Nbr.length;i++){
            Nbr2[i] = tplListService.removeById(seq[i]);
        }

        return  ResponseHelper.buildResponse(Nbr2);
    }


    /**
     * 根据sequenceNbr查询
     *
     * @param sequenceNbr 主键
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY, needAuth = false)
    @GetMapping(value = "/{sequenceNbr}")
    @ApiOperation(httpMethod = "GET", value = "根据sequenceNbr查询单个", notes = "根据sequenceNbr查询单个")
    public ResponseModel<TplListModel> selectOne(@PathVariable Long sequenceNbr) {
        return ResponseHelper.buildResponse(tplListService.queryBySeq(sequenceNbr));
    }


    /**
     * 列表分页查询
     *
     * @param current 当前页
     * @param size    每页大小
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY, needAuth = false)
    @GetMapping(value = "/page")
    @ApiOperation(httpMethod = "GET", value = "分页查询", notes = "分页查询")
    public ResponseModel<Page<TplListModel>> queryForPage(@RequestParam(value = "current") int current, @RequestParam(value = "size") int size, @RequestParam(value = "categorySeq") Long categorySeq, @RequestParam(value = "displayName", required = false) String displayName) {
        Page<TplListModel> page = new Page<>();
        page.setCurrent(current);
        page.setSize(size);
        return ResponseHelper.buildResponse(tplListService.queryForTplListPage(page, categorySeq, displayName));
    }

    /**
     * 列表全部数据查询
     */
    @TycloudOperation(ApiLevel = UserType.AGENCY, needAuth = false)
    @ApiOperation(httpMethod = "GET", value = "列表全部数据查询", notes = "列表全部数据查询")
    @GetMapping(value = "/list")
    public ResponseModel<List<TplListModel>> selectForList() {
        return ResponseHelper.buildResponse(tplListService.queryForTplListList());
    }

//    /**
//     *excel导入
//     *@return
//     */
//    @CrossOrigin
//    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
//    @ApiOperation(httpMethod = "POST",value = "导入",   notes = "导入")
//    @PostMapping(value = "/import")
//    public ResponseModel<List<FileImportModel>> importTpl(@RequestParam("file") MultipartFile multipartFile) throws Exception {
//        ImportParams params = new ImportParams();
////        params.setHeadRows(0);
//        params.setTitleRows(0);
//        List<FileImportModel> fileImportModels =
//                ExcelImportUtil.importExcel(multipartFile.getInputStream(), FileImportModel.class, params);
//        for(FileImportModel fileImportModel:fileImportModels){
//            if(fileImportModel.getSequenceNbr() == null)
//                break;
//            TplListModel tplListModel = new TplListModel();
//            BeanUtils.copyProperties(fileImportModel,tplListModel);
//            tplListModel = tplListService.createWithModel(tplListModel);
//        }
//        System.out.println(fileImportModels);
//        return  ResponseHelper.buildResponse(fileImportModels);
//    }

//    /**
//     * 导入
//     */
//    @CrossOrigin
//    @TycloudOperation(ApiLevel = UserType.AGENCY,needAuth = false)
//    @ApiOperation(httpMethod = "POST",value = "导入",   notes = "导入")
//    @PostMapping(value = "/import")
//    public static JSONArray getJSONArray(String url) {
//        // input存放json内容
//        String input = null;
//
//        // 读取json文件
//        File myFile = new File(url);
//        try {
//            input = FileUtils.readFileToString(myFile, "UTF-8");
//        } catch (IOException e) {
//            e.printStackTrace();
//        }
//
//        // 将数组json转换为JSON数组对象
//        JSONArray jsonArray = JSON.parseArray(input);
//
//        return jsonArray;
//    }


}